@@ -12,7 +12,7 @@ class is_wic_at_nutritional_risk(Variable):
     def formula(person, period, parameters):
         wic_reported = person("receives_wic", period)
         meets_income_test = person.spm_unit("meets_wic_income_test", period)
-        meets_categorical_test = person.spm_unit(
+        meets_categorical_test = person(
             "meets_wic_categorical_eligibility", period
         )
         category = person("wic_category", period)
